/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.msm;

import java.util.*;
import javax.swing.DefaultComboBoxModel;
import org.greenstone.gatherer.msm.MetadataSetManager;
import org.greenstone.gatherer.msm.MSMEvent;
import org.greenstone.gatherer.msm.MSMListener;
import org.w3c.dom.*;

/** A combobox model that contains information from the metadata set manager.
 * @see org.greenstone.gatherer.msm.MetadataSetManager*/
public class MetadataComboBoxModel
    extends DefaultComboBoxModel 
    implements MSMListener {
    private MetadataSetManager msm = null;
    /** Constructor.
     * @param msm The <strong>MetadataSetManager</strong> this model is proxied to.
     */
    public MetadataComboBoxModel(MetadataSetManager msm) {
	super();
	this.msm = msm;
	init();
    }
    /** Called whenever a metadata element is changed.
     * @param event A <strong>MSMEvent</strong> containing pertinent information about the event.
     */
    public void elementChanged(MSMEvent event) {
	init();
    }
    /** Called whenever a metadata value is changed.
     * @param event A <strong>MSMEvent</strong> containing pertinent information about the event.
     */
    public void metadataChanged(MSMEvent event) {
	// Don't care.
    }
    /** Called whenever a metadata set is changed.
     * @param event A <strong>MSMEvent</strong> containing pertinent information about the event.
     */
    public void setChanged(MSMEvent event) {
	init();
    }
    /** Called whenever the value tree of a certain element is significantly changed.
     * @param event A <strong>MSMEvent</strong> containing information about the event.
     */
    public void valueChanged(MSMEvent event) {
	// Don't care.
    }
    private void init() {
	removeAllElements();
	Vector elements = msm.getElements();
	Collections.sort(elements);
	for(int k = 0; k < elements.size(); k++) {
	    addElement(elements.get(k));
	}
    }
}
